@@ -3,4 +3,4 @@
 import typing as t
 
 # https://github.com/python/typing/issues/182
-JSON = t.Union[str, int, float, bool, None, t.Dict[str, 'JSON'], list['JSON']]
+JSON = t.Union[str, int, float, bool, None, t.Dict[str, 'JSON'], t.List['JSON']]
